summaryrefslogtreecommitdiffstats
path: root/kopete/plugins/autoreplace/autoreplacepreferences.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/plugins/autoreplace/autoreplacepreferences.cpp')
-rw-r--r--kopete/plugins/autoreplace/autoreplacepreferences.cpp62
1 files changed, 31 insertions, 31 deletions
diff --git a/kopete/plugins/autoreplace/autoreplacepreferences.cpp b/kopete/plugins/autoreplace/autoreplacepreferences.cpp
index 0a2a6b0f..4f852610 100644
--- a/kopete/plugins/autoreplace/autoreplacepreferences.cpp
+++ b/kopete/plugins/autoreplace/autoreplacepreferences.cpp
@@ -15,12 +15,12 @@
* *
***************************************************************************/
-#include <qcheckbox.h>
-#include <qlayout.h>
-#include <qpushbutton.h>
-#include <qgroupbox.h>
-#include <qheader.h>
-#include <qlistview.h>
+#include <tqcheckbox.h>
+#include <tqlayout.h>
+#include <tqpushbutton.h>
+#include <tqgroupbox.h>
+#include <tqheader.h>
+#include <tqlistview.h>
#include <klocale.h>
#include <klineedit.h>
@@ -36,10 +36,10 @@ typedef KGenericFactory<AutoReplacePreferences> AutoReplacePreferencesFactory;
K_EXPORT_COMPONENT_FACTORY( kcm_kopete_autoreplace, AutoReplacePreferencesFactory( "kcm_kopete_autoreplace" ) )
-AutoReplacePreferences::AutoReplacePreferences( QWidget *parent, const char * /* name */, const QStringList &args )
+AutoReplacePreferences::AutoReplacePreferences( TQWidget *parent, const char * /* name */, const TQStringList &args )
: KCAutoConfigModule( AutoReplacePreferencesFactory::instance(), parent, args )
{
- ( new QVBoxLayout( this ) )->setAutoAdd( true );
+ ( new TQVBoxLayout( this ) )->setAutoAdd( true );
preferencesDialog = new AutoReplacePrefsUI( this );
// creates table columns (avoids new columns every time)
@@ -48,16 +48,16 @@ AutoReplacePreferences::AutoReplacePreferences( QWidget *parent, const char * /*
preferencesDialog->m_list->header()->setStretchEnabled( true , 1 );
// connect SIGNALS/SLOTS
- connect( preferencesDialog->m_add, SIGNAL(pressed()),
- SLOT( slotAddCouple()) );
- connect( preferencesDialog->m_edit, SIGNAL(pressed()),
- SLOT( slotEditCouple()) );
- connect( preferencesDialog->m_remove, SIGNAL(pressed()),
- SLOT(slotRemoveCouple()) );
- connect( preferencesDialog->m_list, SIGNAL(selectionChanged()),
- SLOT(slotSelectionChanged()) );
- connect( preferencesDialog->m_key, SIGNAL(textChanged ( const QString & )),
- SLOT( slotEnableAddEdit( const QString & )) );
+ connect( preferencesDialog->m_add, TQT_SIGNAL(pressed()),
+ TQT_SLOT( slotAddCouple()) );
+ connect( preferencesDialog->m_edit, TQT_SIGNAL(pressed()),
+ TQT_SLOT( slotEditCouple()) );
+ connect( preferencesDialog->m_remove, TQT_SIGNAL(pressed()),
+ TQT_SLOT(slotRemoveCouple()) );
+ connect( preferencesDialog->m_list, TQT_SIGNAL(selectionChanged()),
+ TQT_SLOT(slotSelectionChanged()) );
+ connect( preferencesDialog->m_key, TQT_SIGNAL(textChanged ( const TQString & )),
+ TQT_SLOT( slotEnableAddEdit( const TQString & )) );
m_wordListChanged = false;
@@ -90,7 +90,7 @@ void AutoReplacePreferences::load()
for ( it = map.begin(); it != map.end(); ++it )
{
// notice: insertItem is called automatically by the constructor
- new QListViewItem( preferencesDialog->m_list, it.key(), it.data() );
+ new TQListViewItem( preferencesDialog->m_list, it.key(), it.data() );
}
m_wordListChanged = false;
@@ -102,7 +102,7 @@ void AutoReplacePreferences::save()
{
// make a list reading all values from gui
AutoReplaceConfig::WordsToReplace newWords;
- for ( QListViewItem * i = preferencesDialog->m_list->firstChild(); i != 0; i = i->nextSibling() )
+ for ( TQListViewItem * i = preferencesDialog->m_list->firstChild(); i != 0; i = i->nextSibling() )
newWords[ i->text( 0 ) ] = i->text( 1 );
// save the words list
@@ -116,16 +116,16 @@ void AutoReplacePreferences::save()
// read m_key m_value, create a QListViewItem
void AutoReplacePreferences::slotAddCouple()
{
- QString k = preferencesDialog->m_key->text();
- QString v = preferencesDialog->m_value->text();
+ TQString k = preferencesDialog->m_key->text();
+ TQString v = preferencesDialog->m_value->text();
if ( !k.isEmpty() && !k.isNull() && !v.isEmpty() && !v.isNull() )
{
- QListViewItem * lvi;
- QListViewItem * oldLvi = 0;
+ TQListViewItem * lvi;
+ TQListViewItem * oldLvi = 0;
// see if we are replacing an existing entry
if ( ( oldLvi = preferencesDialog->m_list->findItem( k, 0 ) ) )
delete oldLvi;
- lvi = new QListViewItem( preferencesDialog->m_list, k, v );
+ lvi = new TQListViewItem( preferencesDialog->m_list, k, v );
// Triggers a size, geometry and content update
// during the next iteration of the event loop
preferencesDialog->m_list->triggerUpdate();
@@ -140,9 +140,9 @@ void AutoReplacePreferences::slotAddCouple()
// edit the selected item
void AutoReplacePreferences::slotEditCouple()
{
- QString k = preferencesDialog->m_key->text();
- QString v = preferencesDialog->m_value->text();
- QListViewItem * lvi;
+ TQString k = preferencesDialog->m_key->text();
+ TQString v = preferencesDialog->m_value->text();
+ TQListViewItem * lvi;
if ( ( lvi = preferencesDialog->m_list->selectedItem() ) && !k.isEmpty() && !k.isNull() && !v.isEmpty() && !v.isNull() )
{
lvi->setText( 0, k );
@@ -163,7 +163,7 @@ void AutoReplacePreferences::slotRemoveCouple()
slotWidgetModified();
}
-void AutoReplacePreferences::slotEnableAddEdit( const QString & keyText )
+void AutoReplacePreferences::slotEnableAddEdit( const TQString & keyText )
{
preferencesDialog->m_add->setEnabled( !keyText.isEmpty() );
preferencesDialog->m_edit->setEnabled( !keyText.isEmpty() && preferencesDialog->m_list->selectedItem() );
@@ -171,7 +171,7 @@ void AutoReplacePreferences::slotEnableAddEdit( const QString & keyText )
void AutoReplacePreferences::slotSelectionChanged()
{
- QListViewItem *selection = 0;
+ TQListViewItem *selection = 0;
if ( ( selection = preferencesDialog->m_list->selectedItem() ) )
{
// enable the remove button
@@ -203,7 +203,7 @@ void AutoReplacePreferences::defaults()
for ( it = map.begin(); it != map.end(); ++it )
{
// notice: insertItem is called automatically by the constructor
- new QListViewItem( preferencesDialog->m_list, it.key(), it.data() );
+ new TQListViewItem( preferencesDialog->m_list, it.key(), it.data() );
}
m_wordListChanged = true;
slotWidgetModified();